@@ -34,7 +34,12 @@ from contextlib import contextmanager
 from typing import List, Optional, Union
 from xml.etree import ElementTree as ET
 
-import toml
+
+if sys.version_info >= (3, 11):
+    import tomllib  # pragma: nocover
+else:
+    import tomli as tomllib  # pragma: nocover
+
 from setuptools.command.egg_info import translate_pattern
 
 
@@ -42,7 +47,7 @@ from setuptools.command.egg_info import translate_pattern
 from distutils.text_file import TextFile  # isort:skip
 
 
-__version__ = '0.46'
+__version__ = '0.49'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'MIT'
 __url__ = 'https://github.com/mgedmin/check-manifest'
@@ -395,14 +400,10 @@ class Git(VCS):
         # .git can be a file for submodules
         return os.path.exists(os.path.join(location, cls.metadata_name))
 
-    def _has_submodules(cls):
-        return os.path.exists(".gitmodules")
-
     def get_versioned_files(self):
         """List all files versioned by git in the current directory."""
-        extra_args = ["--recurse-submodules"] if self._has_submodules() else []
         output = run(
-            ["git", "ls-files", "-z"] + extra_args,
+            ["git", "ls-files", "-z", "--recurse-submodules"],
             encoding=self._encoding,
         )
         # -z tells git to use \0 as a line terminator; split() treats it as a
@@ -577,6 +578,8 @@ class IgnoreList:
             # GitHub template files
             .prune('.github')
             # we can do without these in sdists
+            .global_exclude('.circleci/config.yml')
+            .global_exclude('.gitpod.yml')
             .global_exclude('.travis.yml')
             .global_exclude('Jenkinsfile')
             # It's convenient to ship compiled .mo files in sdists, but they
@@ -699,7 +702,8 @@ def _load_config():
 
     """
     if os.path.exists("pyproject.toml"):
-        config = toml.load("pyproject.toml")
+        with open('pyproject.toml', 'rb') as f:
+            config = tomllib.load(f)
         if CFG_SECTION_CHECK_MANIFEST in config.get("tool", {}):
             return config["tool"][CFG_SECTION_CHECK_MANIFEST]
 
@@ -879,7 +883,7 @@ def extract_version_from_filename(filename):
     filename = os.path.splitext(os.path.basename(filename))[0]
     if filename.endswith('.tar'):
         filename = os.path.splitext(filename)[0]
-    return filename.partition('-')[2]
+    return filename.split('-')[-1]
 
 
 def should_use_pep_517():
@@ -890,7 +894,8 @@ def should_use_pep_517():
     # should revert to the legacy behaviour of running setup.py".
     if not os.path.exists('pyproject.toml'):
         return False
-    config = toml.load("pyproject.toml")
+    with open('pyproject.toml', 'rb') as f:
+        config = tomllib.load(f)
     if "build-system" not in config:
         return False
     if "build-backend" not in config["build-system"]:
